@@ -1,12 +1,12 @@
 ;;; consult-flycheck.el --- Provides the command `consult-flycheck' -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2025 Daniel Mendler
+;; Copyright (C) 2021-2026 Daniel Mendler
 
 ;; Author: Daniel Mendler and Consult contributors
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2020
-;; Package-Version: 20250923.1114
-;; Package-Revision: 062e223bc6cf
+;; Package-Version: 20260117.1654
+;; Package-Revision: 9fe96c4b75c8
 ;; Package-Requires: ((emacs "29.1") (consult "2.8") (flycheck "35"))
 ;; URL: https://github.com/minad/consult-flycheck
 ;; Keywords: languages, tools, completion
@@ -48,10 +48,10 @@ In contrast to `flycheck-error-level-<' sort errors first."
          (ly (flycheck-error-level y))
          (sx (flycheck-error-level-severity lx))
          (sy (flycheck-error-level-severity ly))
-         (fx (if-let ((file (flycheck-error-filename x)))
+         (fx (if-let* ((file (flycheck-error-filename x)))
                  (file-name-nondirectory file)
                (buffer-name (flycheck-error-buffer x))))
-         (fy (if-let ((file (flycheck-error-filename y)))
+         (fy (if-let* ((file (flycheck-error-filename y)))
                  (file-name-nondirectory file)
                (buffer-name (flycheck-error-buffer y)))))
     (if (string= fx fy)
@@ -70,7 +70,7 @@ In contrast to `flycheck-error-level-<' sort errors first."
   (let* ((errors (mapcar
                   (lambda (err)
                     (list
-                     (if-let (file (flycheck-error-filename err))
+                     (if-let* ((file (flycheck-error-filename err)))
                          (file-name-nondirectory file)
                        (buffer-name (flycheck-error-buffer err)))
                      (number-to-string (flycheck-error-line err))
